/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2016, 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/

var Promise = require('bluebird');
var createFiles = require('./factory').createFiles;
var createWSDLSwagger = require('./factory').createWSDLSwagger;
var g = require('strong-globalize')();
var prompt = require('./prompt');

module.exports.createApi = function createApi(options) {
  if (options.wsdl) {
    var programs = {
      wsdl: options.wsdl,
      product: options.product,
    };
    return createWSDLSwagger(programs);
  } else {
    if (typeof options.name !== 'string') {
      options.name = null;
    }
    if (typeof options.version !== 'string') {
      options.version = null;
    }
    if (!options.title && (options.name
      || options.version
      || options.basepath
      || options.product
      || options.template
      || options.filename
      || options.hostname
      || options.schemes
      || options.target_url)) {
      return new Promise(function(resolve, reject) {
        return reject(new Error(
          g.f('The {{--title}} option and a value are required to run in non-interactive mode.'))
        );
      });
    }
  }
  return prompt(options).then(function(data) {
    return createFiles(data);
  });
};

module.exports.createProduct = function createProduct(options) {
  if (typeof options.name !== 'string') {
    options.name = null;
  }
  if (typeof options.version !== 'string') {
    options.version = null;
  }

  if (!options.title && (options.name
    || options.version
    || options.basepath
    || options.product
    || options.template
    || options.filename
    || options.apis)) {
    return new Promise(function(resolve, reject) {
      return reject(new Error(g.f('The {{--title}} option and a value are required to run in non-interactive mode.')));
    });
  }
  return prompt(options).then(function(data) {
    return createFiles(data);
  });
};

